#
# spec file for package cmake (Version 2.8.2)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           cmake
Version:        2.8.2
Release:        3.1
License:        BSD3c
Group:          Development/Tools/Building
Url:            http://www.cmake.org/
Source0:        %{name}-%{version}.tar.bz2
Patch4:         cmake-disable-builtin-chrpath.diff
Patch5:         fortify-buffer-overflows.diff
Patch6:         cmake-support-new-python.diff
# Should appear in cmake-2.8.3
Patch7:         cmake-FindGTK2-gdk-pixbuf.patch
Summary:        Cross-platform, open-source make system
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version}
BuildRequires:  libexpat-devel
%if 0%{?suse_version} > 1110
BuildRequires:  fdupes
%endif
%else
BuildRequires:  expat-devel
%endif
BuildRequires:  curl-devel
BuildRequires:  gcc-c++
BuildRequires:  ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  zlib-devel
Requires:       make

%description
CMake is a cross-platform, open-source make system

Authors:
--------
    Kitware, Inc., Insight Consortium

%prep
%setup -q -n %{name}-%{version}
%patch4
%patch5
%patch6 -p1
%patch7 -p1

%build
export CXXFLAGS="$RPM_OPT_FLAGS"
export CFLAGS="$CXXFLAGS"
./configure \
    --prefix=%{_prefix} \
    --datadir=/share/%{name} \
    --docdir=/share/doc/packages/%{name} \
    --mandir=/share/man \
    --system-libs \
    --parallel=0%jobs \
    --no-qt-gui
make VERBOSE=1 %{?jobs:-j %jobs}

%install
make DESTDIR=%{buildroot} install
mkdir -p %{buildroot}%{_libdir}/cmake
find %{buildroot}/usr/share/cmake -type f -print0 | xargs -0 chmod 644
cp ChangeLog.manual %{buildroot}/usr/share/doc/packages/%{name}/Changelog
%if 0%{?suse_version} >  1110
%fdupes %buildroot/usr/share/cmake
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%{_bindir}/cpack
%{_bindir}/cmake
%{_bindir}/ctest
%{_bindir}/ccmake
%{_datadir}/cmake
%{_libdir}/cmake
%doc %{_datadir}/doc/packages/%{name}
%doc %{_mandir}/man1/cmakepolicies.1.*
%doc %{_mandir}/man1/cmake.1.*
%doc %{_mandir}/man1/ctest.1.*
%doc %{_mandir}/man1/ccmake.1.*
%doc %{_mandir}/man1/cmakecommands.1.*
%doc %{_mandir}/man1/cmakecompat.1.*
%doc %{_mandir}/man1/cmakemodules.1.*
%doc %{_mandir}/man1/cmakeprops.1.*
%doc %{_mandir}/man1/cmakevars.1.*
%doc %{_mandir}/man1/cpack.1.*

%changelog
* Tue Sep 14 2010 puzel@novell.com
- add cmake-FindGTK2-gdk-pixbuf.patch (bnc#635439)
* Mon Sep 13 2010 kkaempf@novell.com
- fix build on RHEL/Fedora
* Tue Sep  7 2010 coolo@novell.com
- support new python 2.7
* Tue Jul 20 2010 puzel@novell.com
- update to cmake-2.8.2
  - notable changes:
  - CPack: Add native BZip2 support
  - ExternalProject: Support .zip and .bz2 archives, MD5 verification
  - GetPrerequisites: Provide an override hook
  - Recognize ARM ABI/EABI with GNU compilers
  - Recognize Clang compiler
  - Search basic directories on "Generic" platform
  - Support compression with 'cmake -E tar'
  - a lot of bugfixes
* Thu Jun 10 2010 dimstar@opensuse.org
- Fix build on Fedora, by not using defaultdocdir. It does not
  match the forced installation path on configure.
* Thu Jun  3 2010 dimstar@opensuse.org
- No fdupes on non-suse platforms and SLE10.
* Tue May 18 2010 puzel@novell.com
- split cmake-gui into different specfile so that cmake
  build does not depend on libqt4
* Thu Mar 18 2010 puzel@novell.com
- update to cmake 2.8.1 (final)
  - Add a new search path for MPICH2
  - Add .git .bzr and .hg to the list of default CPack ignore
    directories.
  - CTest: Do not hide test GUI windows (fixes 2.8.0 regression)
  - Documentation: Clarify CMAKE_MODULE_PATH variable
  - FindQt4: Add support for QtDeclartive module
  - FortranCInterface: Fix PathScale detection
* Wed Feb 24 2010 dmueller@suse.de
- update to cmake 2.8.1 (rc3):
  * many bugfixes
  - CTest: Setup command-line dashboard support with Git
  - CPack: Improve RPM spec files
  - CTest: Improve host system introspection
  - FindCUDA: Respect CUDA version differences
  - FindCURL: Find import libraries on Windows
  - FindGTK2: Look in fink locations on Mac OS X
  - FindJNI: Honor find_package() REQUIRED and QUIET options
  - FindOpenSSL: Fix MinGW support
  - FindPythonLibs: Look in config for static library
  - FindQt4: Misc enhancements, sync with KDE vesion
  - FindX11: Improve documentation
  - link_directories(): Treat relative paths consistently (CMP0015)
  - Modernize FindLibXslt and FindLibXml.cmake
  - UseQt4: Provide dependencies only for static Qt (#10021)
* Sat Feb 13 2010 dmueller@suse.de
- fix fortify related static buffer overflows (not exploitable)
* Fri Nov 27 2009 puzel@suse.cz
- update to cmake-2.8.0
  - noteworthy changes sice 2.6.4:
  - cmake-gui supports multi-state values options.
  - CMake now has cmake --build command that can build any CMake generated
    project from the command line.
  - CTest supports running tests in parallel with a -j N option.
  - It is now possible to use DESTDIR in CPack for any CMake based projects
    giving more flexibility on the final path names.
  - Depend scanning is now much faster with makefiles.
  - Many FindQt4 improvements to stay working with current Qt releases
  - FindBoost has been updated to work with the most recent boost releases.
  - see /usr/share/doc/packages/cmake/Changelog for all changes
- drop ibm-java-paths.diff, cmake-2.6.0-use_shared_python_lib.patch and
  cmake-2.6.0-use_intree_xmlrpc.patch - fixed upstream
* Mon May  4 2009 puzel@suse.cz
- updated to 2.6.4
  - Fix: ctest system information was not always correct on linux
  - Fix transitive linking of imported libraries
  - Fix CDash only submit with ctest_submit
  - Fix scope issue with CMAKE_CURRENT_LIST_FILE  and macros
  - Fix crash in include_directories
  - Do not warn if LIBPATH is not set for nmake
  - No longer mark header files as HEADER_FILE_ONLY automatically,
    this gets rid of the ugly red marks in Visual Stuido
  - Enforce unique binary directories
  - Clarify docs of old *_OUTPUT_PATH vars
  - Fix svn update logic for modified files
  - Add get_filename_component(... REALPATH)
* Mon May  4 2009 dmueller@suse.de
- add %%_libdir/cmake to the file list
* Wed Mar 11 2009 dmueller@suse.de
- build fixes for non-suse distros
* Tue Mar  3 2009 puzel@suse.cz
- update to 2.6.3
  - add parenthetical expressions to if
  - improve scoping of policies (see cmake_policy and CMP0011)
  - teach find_package more config file locations
  - many improved Find scripts in Modules
  - added an unset command
  - better reporting when nmake compiler environment is not correct
  - lots of bug fixes
- use fdupes to remove duplicate files
* Mon Dec 22 2008 ro@suse.de
- Fix java detection also for ia64 s390 s390x
* Mon Oct 13 2008 dmueller@suse.de
- Fix Detection of IBM Java (needed for PPC build of Java modules)
* Tue Sep 30 2008 puzel@suse.cz
- update to 2.6.2:
  - Fixed: cpack did not work when sym-linked after install
  - Add beta BundleUtilities.cmake file
  - CPackRPM 7435 fixes to add optional post-install
  - Fixed: FindBoost versioned find not working
  - Fix FindCurses to be able to work without ncurses.h
  - FindQt4 fixed: add a bit more documentation and add ability
    to specify extra flags to lupdate.
  - Fixed: make llvm-gcc work, by explicitely excluding
    "llvm-" from _CMAKE_TOOLCHAIN_PREFIX
  - Fixed: OS X Framework support: extensionless headers were
    being ignored when specified as public headers
  - Fix documentation in CheckCCompilerFlag.cmake
  - Add better version support to find_package command
  - Fix Xcode debug not working
  - Add VERSION compare to if command
  - Make FindThreads sete THREADS_FOUND
  - Deb cpack generator sets Installed-Size for the package
  - Do not add an empty /D"" at the end of VS 6 .dsp compile lines
  - Recognize /MAP in VS 7 and greater
  - Add new policy CMP0009 - GLOB_RECURSE should not follow symlinks by
    default
  - many other bugfixes - see changelog
* Sun Aug  3 2008 dmueller@suse.de
- update to 2.6.1:
  * Fix for bug 7427, preinstall target name hard coded
* Wed Jul 23 2008 dmueller@suse.de
- update to 2.6.1-RC15:
  * FindMPI: Use the HINTS feature of find_library to find the right
  libraries for MPI, and act a bit more intelligently when MPI cannot be found.
  * moved CMAKE_CROSSCOMPILING from "Variables that modify behaviour" to
  "variables that Provide Information"
  * handle HTML documentation for single items better: no warning about
  * ComputeSectionLinkPrefix, don't create an index for only one item.
  * Better error messages in CPackBundleGenerator
  * Fix bug 7426 FindJPEG module causes error when setting JPEG_LIBRARY to blank
  * Fix bug 7414 PackageMaker generator crashes when given components
    with circular dependencies
  * Fix source files to not add extra /, and look for extensions for
    all enabled languages.
* Mon Jul 21 2008 dmueller@suse.de
- update to 2.6.1-RC11:
  * FindBoost can now find the upcoming Boost 1.46
  * More fixes for CPack components functionality
  * Fix FindQt4.cmake with empty qconfig.pri files.  Fixes #7287.
  * Fix column width in cmake-gui
* Wed Jul  2 2008 dmueller@suse.de
- update to 2.6.1-RC6:
  * Fix DEFINITIONS property to be compatible with 2.4
  * FindGettext.cmake  fix bug #7230: don't ignore first parameter if it's
    not ALL
  * Add support for component based packages in cpack.
  * Fix FindKDE3.cmake to not add flags if kde3 is not found
  * Fix FindMatlab.cmake, FindOpenSSL.cmake, FindQt3.cmake,
    FindSWIG.cmake, to only error if it is required
  * Change to find_*, a new HINTS keyword was added to avoid the
    need for NO_DEFAULT_PATH, and a repeated call to find_*
  * Update all NO_DEFAULT_PATH usage in Modules/Find*
  * Fix for cpack self extracting .sh files to work with more shells
  * FindQt4 now finds dependencies for some qt modules
  * Give a message if rpath is changed during install
  * rpath changer during install understands symlinks now
  * FindQt4 - make Qt not found if the QtCore library can't be found.
  * UseQt4 - only add flags for modles that are used
  * Fix incorrect extension extraction in gcc cross compiler check
  * Add a way to modify depend scanning with the property:
    IMPLICIT_DEPENDS_INCLUDE_TRANSFORM
  * Fix -Wno-dev to not eat path to source tree
  * Fix FindBoost version variable names to correct bug in Boost version
  * Fix bug 0006990 CMake crashes with bad input to
    set_source_files_properties
  * Fix bug in FindCurses where you could not run cmake twice
* Thu Jun 12 2008 mrdocs@opensuse.org
- add %%ifdefs to disable the cmake gui for non-Suse distros
- SLES 9 does not build, but its a compile failure
* Fri May  9 2008 dmueller@suse.de
- fix ctest reporting (kitware#6988), patch by Andreas Schneider
* Tue May  6 2008 dmueller@suse.de
- update to 2.6.0:
  * Fix links in generated documentation
  * Fix for FindQt and some mac frameworks
  * Fix for ctest to report more than 2 gigs system memory on windows
  * Fix CTest build name for vs 9, and fix memory size on windows
* Fri May  2 2008 dmueller@suse.de
- update to 2.6.0 RC10:
  - Do not duplicate .so libraries on the link line
  - Add more system library paths to sun builds
  - Add BETA support for Intel Fortran IDE files in visual studio
  - Fix FindCurses to work if ncurses is the only option
  - Fix shell escapes on some systems
  - Remove check for file write as input to cmake, as it is no longer needed
  - Make check_type_size automatically check for headers that it uses
  - Remove minimum required from FindBoost.cmake
  - Fix FindSDL so that it can be run more than once
  - Fix find required for VTK package
  - Allow for CMAKE_OSX_SYSROOT to work with single architecture
  - Add context information when a source file cannot be found.
  - Report the directory-level context even if no list file
  is currently being processed.
* Mon Apr 28 2008 dmueller@suse.de
- fix curses detection (readds previously lost ccmake)
* Thu Apr 24 2008 dmueller@suse.de
- update to 2.6.0 RC9:
  - Fix for fortran mod:: support
  - Fix bug in install command with BUNDLE DESTINATION
  - Make mac install symlinks check for errors
  - Fix for CMP0007, to not warn about empty lists
  - Preserve static libraries when linked multiple times
  - Use c compiler path to find asm compiler
  - Allow RC compiler to not get all COMPILE_FLAGS
  - Complete overhaul for FindBoost.cmake
  - Minor fixes for FindMPI.cmake
  - Fix for list command and empty list elements CMP0007
  - Fix for VS6 and sub-groups
  - Fix bug 6440, and make sure _INIT flags do not overright cache values
  - Do not report CMP0003 for anything other than -l
  - Fix crash in fortran depend scanning, bug 6855
  - Fix timeout values for cmake's own tests
  - Better message in compiler ABI detect
  - Fixes for cpack x11 packages on leopard
  - Changes to cpack options names
  - Fixes for FindMPI on 64 bit MS MPI
  - Fix for -isystem for wxWidgets
  - Some fixes for chrpath during installation
  - Fix compatibility with CMake 2.4 for installation of MACOSX_BUNDLE (CMP0006)
  - Do not use debug postfix when building frameworks on the Mac
  - Fix exception handling off/on issue with visual studio IDE generators
  - Fix <OBJECT_DIR> to be native path style
  - Fix leak in cpack
  - Some Qt GUI style changes
* Sat Apr 19 2008 dmueller@suse.de
- fix python lib detection again
* Mon Apr 14 2008 dmueller@suse.de
- update to 2.6.0 RC8:
  * Fix sun make very poor performance
  * Fix includes for automoc in FindQt4
* Wed Apr  9 2008 dmueller@suse.de
- update to 2.6.0 RC6:
  * last RC before 2.6.0
  * new graphical cmake ui
  * faster install
* Fri Feb 29 2008 adrian@suse.de
- use rpm macros for pathes
- fix build for Mandriva
* Fri Feb  1 2008 pcerny@suse.cz
- spec file update to build in BS in all distributions
* Mon Jan 28 2008 dmueller@suse.de
- update to 2.4.8:
  * version number increase, no linux specific changes
* Fri Jan 25 2008 pcerny@suse.cz
- added zlib to BuildRequires
* Mon Jan 21 2008 coolo@suse.de
- always buildrequire openssl-devel
* Mon Jan 14 2008 dmueller@suse.de
- update to 2.4.8-RC12:
  * fix glib and Qt4 detection on 10.2 and older
  * MODULE install with versions was broken
* Thu Jan  3 2008 dmueller@suse.de
- update to 2.4.8-RC9:
  * last release candidate of 2.4.8
  * Add list(FIND) because it is used in new FindQt4.cmake
  * Fix tar long file path issue with cpack
  * Fix variable name in docs for FindPkgConfig bug 5722
  * Fix for bug 5645 ifort bad pic flag on linux
  * Fix for bug 6006 INSTALL DIRECTORY signature problem
  * Update FindQt4 from CVS Head for many bug fixes
  * Fix bug 5638 CMAKE_INSTALL_PREFIX not working on SunOS with CC
  * Fix bug 6117 FindPkgConfig can run twice now
  * Fix bug 6106 FindPerlLibs.cmake missing escaped $
  * Allow NODEFAULTLIBS to have more than one value bug 5455
  * fix for bug 5363: GET_TARGET_PROPERTY(... DEBUG_LOCATION)
  * Better error from ctest if nightly time not set
  * Avoid relinking exclude-from-all directory targets before install
  * Fix for kde4-config location
  * Remove KDE3_ENABLE_FINAL (did not work)
  * KDE3 fix for 64 bit location of plugins
  * mark PYTHON_EXECUTABLE as advanced
  * documentation fix for file, find_package, try_run
  * add IS_ABSOLUTE to if
  * INSTALL() everything which doesn't have a COMPONENT set, is assigned
  * make #cmakedefine output match autoconf when undefined
  * document cmake remove -f
  * document order of -D and -P
* Mon Dec 10 2007 dmueller@suse.de
- if you want cmake, you probably also want make
* Fri Sep 21 2007 dmueller@suse.de
- disabling less_verbosity patch
* Fri Jul 20 2007 pcerny@suse.cz
- update to 2.4.7 - several bugfixes
  (KDevelop problem among others,
  see ChangeLog.manual for more details)
* Fri Apr 27 2007 dmueller@suse.de
- expat -> libexpat-devel
* Thu Mar 29 2007 dmueller@suse.de
- add ncurses-devel buildrequires
* Thu Jan 11 2007 dmueller@suse.de
- update to 2.4.6:
  * Fix for FIND_* order and framworks with PREFIX usage.
  * Fix for FindDoxygen and quiet mode.
  * Find JavaVM as well as jvm
  * Look for ruby1.8 and ruby
  * Fix for cpack .tgz.sh and dash
  * Fix for finding custom commands from a full path with CMAKE_CFG_INTDIR.
  * Fix for Borland make and custom commands that do nothing
* Mon Jan  8 2007 dmueller@suse.de
- readd patch to detect shared python library instead of
  the static one.
* Tue Dec 19 2006 mrueckert@suse.de
- added cmake-2.4.5_use_intree_xmlrpc.patch:
  the xmlrpc-c check seems broken. and on 10.2 we dont have the lib
  anyways. so disable the systemwide xmlrpc for now.
* Fri Dec 15 2006 mrueckert@suse.de
- update to version 2.4.5:
  * Fix for seg fault when a macro runs a bad command BUG# 3815
  * Fix fix for foo.dll.lib that does not break -L/usr/lib in
    link names
  * Fix problem with LIBRARY_OUTPUT_PATH and linking to a dll
    foo.dll.lib instead of foo.lib
  * Do not depend on optimized libraries for a debug build and
    visa versa.
  * Fix target name matching custom command output conflict.
  * Fix FindQt3 so that it does not find qt4
  * Fix FindKDE4 so that it only looks for kde4-config
- disabled all patches -> applied upstream
* Mon Oct  2 2006 dmueller@suse.de
- detect shared python library instead of static variant
* Tue Sep 26 2006 dmueller@suse.de
- add python 2.5 support
* Sat Sep  9 2006 dmueller@suse.de
- build against system zlib / libcurl
* Mon Aug 28 2006 coolo@suse.de
- fix Qt3 configure check for lib64
* Sat Aug 26 2006 coolo@suse.de
- respect DESTDIR on installing kde3 icons
* Mon Aug 14 2006 coolo@suse.de
- add SUSE default paths for Qt3
* Mon Jul 31 2006 dmueller@suse.de
- 2.4.3 update:
  * progress is now reported with makefiles
  * Fix relative path problems in ADD_SUBDIRECTORY
  * Fix crash in CMakeSetup when status line is long
  * make sure try compile files have a newline at the end
  * add rxvt-unicode, cygwin, and screen terminal support for color
  output
* Wed May 17 2006 dmueller@suse.de
- 2.4.2 update:
  * Run symlink command from correct directory for executable versions
  * Fix for universal binaries and Xcode depend problem
  * Changes to LIST command, see --help-command LIST
  * Fix FindQT to be able to use full paths to source files
  * Fix CPack ZIP on windows command line problem
  * Find executables with no extension on windows mingw
  * Fix FindQt3 to use QTDIR over path
  * Significant speedup in try-compile for nmake
  * CPack improvements including tar bzip2
  * FindQt4 windows path fix
  * Sunos cc optimize flags are correct
  * Fix crash with ${} empty variable
  * Increase depend speed on Mac OS.
  * install command CONFIGURATIONS option.
  * Fix MSVC60, MSVC70, MSVC71, MSVC80 definitions for IDE builds
  * Fix for C++ compiler being used for c code in VS IDE
* Wed May 10 2006 dmueller@suse.de
- 2.4.1 update :
  * Several ctest and cpack bug fixes
  * Many updates and fixes for FindQt4.cmake
  * Fix CMAKE_REQUIRED_FLAGS in CheckCXXSourceCompiles.cmake
  * Handle running make from a symlinked build tree
  * Automatic color ouput detection for shells building with make
  * Kdevelop generator handles CMakeFiles directory better
  * add correct depend information for fluid
  * allow the cache to be saved even if a fatal error occurs
  * fix bug in relative path subdir and add_subdirectoy commands
  * support in vs for two object files with the same name
  * short file names used for library paths in visual studio
  * package target only shows up when you have cpack config files
  * Use dl and not -ldl for adding in the dynamic library
  * Fix check c/cxx source compiles macros to not clobber log files
  * Fix nmake version detection of cl and create correct pdb files
  * Fix msys bootstrap
  * Change color output to be more readable
  * Fix vs6 library naming
* Tue Apr 18 2006 dmueller@suse.de
- update to 2.4.0, fixes -L/-I compiler flag ordering
  needed for building KDE 4 trunk.
* Thu Apr 13 2006 dmueller@suse.de
- fix --help-modules / --help-module <module>
* Mon Mar 27 2006 dmueller@suse.de
- compile with RPM_OPT_FLAGS (#160857)
- fix permissions of installed files (#160856)
* Fri Mar 24 2006 dmueller@suse.de
- drop rpath patch, no longer necessary
* Mon Mar 20 2006 dmueller@suse.de
- CVS snapshot update, fixes RPATH handling
* Wed Feb 15 2006 dmueller@suse.de
- Initial package (2.3 CVS snapshot 20060210)
